//
//  TimerModel.swift
//  Timer
//
//  Designed by Lech Szymanski in 2014.
//  Swift implementation by David Eyers in 2015.
//  Updated for Swift 4.x / Xcode 9.4 in 2018 by Hamza Bennani.
//

import Foundation

open class TimerModel: NSObject {
    @objc dynamic var seconds:Int = 0
    var stopping:Bool = false
    
    @objc open dynamic var running:Bool = false
    
    // the OS's NSTimer will callback here
    @objc func countUp(_ theTimer:Foundation.Timer) {
        if(!stopping) {
            seconds += 1
        } else {
            theTimer.invalidate()
            running = false
            stopping = false
        }
    }
    
    open func start() {
        if(running) { return }
        
        // Create a timer object that calls the countUp method every second
        let timer = Foundation.Timer(timeInterval: 1, target: self, selector: #selector(TimerModel.countUp(_:)), userInfo: nil, repeats: true)
        
        // Get a reference to the current event loop
        let loop = RunLoop.current
        
        // Attach the above timer to the event loop:
        // it will then actually start firning
        loop.add(timer, forMode: RunLoopMode.commonModes)
        
        // Change our internal state to running
        running = true
    }
    open func stop() {
        stopping = true
    }
    open func reset() {
        seconds = 0
    }
}
